
Authors
=======

This python wrapper is made by:

* Karl M. Laundal
* Christer van der Meeren
* Angeline G. Burrell (maintainer)

Fortran code by Emmert et al. [2010] [1]_. Quasi-dipole and modified
apex coordinates are defined by Richmond [1995] [2]_. The code uses
IGRF-12 with coefficients valid through 2020 [Thébault et al., 2015] [3]_.

.. [1] Emmert, J. T., A. D. Richmond, and D. P. Drob (2010),
       A computationally compact representation of Magnetic-Apex
       and Quasi-Dipole coordinates with smooth base vectors,
       J. Geophys. Res., 115(A8), A08322, :doi:`10.1029/2010JA015326`.

.. [2] Richmond, A. D. (1995), Ionospheric Electrodynamics Using
       Magnetic Apex Coordinates, Journal of geomagnetism and
       geoelectricity, 47(2), 191–212, :doi:`10.5636/jgg.47.191`.

.. [3] Thébault, E. et al. (2015), International Geomagnetic Reference
       Field: the 12th generation, Earth, Planets and Space, 67(1), 79,
       :doi:`10.1186/s40623-015-0228-9`.
